summaryrefslogtreecommitdiffstats
path: root/kmail/folderrequester.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderrequester.h')
-rw-r--r--kmail/folderrequester.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kmail/folderrequester.h b/kmail/folderrequester.h
index 9d7493c8..a13ab6d2 100644
--- a/kmail/folderrequester.h
+++ b/kmail/folderrequester.h
@@ -16,11 +16,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -38,22 +38,23 @@ class KMFolderTree;
namespace KMail {
/**
- * A widget that tqcontains a KLineEdit which shows the current folder
+ * A widget that contains a KLineEdit which shows the current folder
* and a button that fires a KMFolderSelDlg
* The dialog is set to disable readonly folders by default
* Search folders are excluded
*/
- class FolderRequester: public QWidget
+ class FolderRequester: public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent the parent widget
* @param tree the KMFolderTree to get the folders
*/
- FolderRequester( TQWidget *parent, KMFolderTree* tree );
+ FolderRequester( TQWidget *tqparent, KMFolderTree* tree );
virtual ~FolderRequester();
/** Returns selected folder */
@@ -38,22 +38,23 @@ class KMFolderTree;
/**
* Constructor
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param tree the KMFolderTree to get the folders
*/